import { DiscoveredSource } from './types';
import { Axios } from 'axios';
export interface DiscoveryOptions {
    /**
     * The Axios instance for the HTTP requests
     */
    axios?: Axios;
    /**
     * Whether it will prioritize Atom and RSS feeds over the Wordpress REST API
     *
     * Defaults to false
     */
    preferFeeds?: boolean;
    /**
     * Whether the source can be used. By default, all sources can be used.
     *
     * @param source The found source
     */
    canUseSource?: (source: DiscoveredSource) => boolean;
    /**
     * Whether a few paths should be tested in case no metadata can be auto-discovered
     * in order to try to find a valid data source
     *
     * Defaults to false
     */
    tryToGuessPaths?: boolean;
    /**
     * The RSS and Atom feed paths that are going to be tested.
     *
     * Only used when `tryToGuessPaths` is set to true.
     *
     * Defaults to ['./feed', './atom', './rss', './feed.json', './feed.xml', '?feed=atom']
     */
    feedPaths?: string[];
    /**
     * The Wordpress API paths that are going to be tested.
     *
     * Only used when `tryToGuessPaths` is set to true.
     *
     * Defaults to ['./wp-json', '?rest_route=/']
     */
    wpApiPaths?: string[];
}
/**
 * Looks through a site metadata in order to find a data source such as a Feed RSS.
 *
 * It's recommended to call this function once, as blog data sources rarely change.
 *
 * @param url The site URL
 * @param options The discovery options
 * @throws Error When no post source is available
 */
export declare function discoverPostSource(url: string, options?: DiscoveryOptions): Promise<DiscoveredSource>;
//# sourceMappingURL=discoverPostSource.d.ts.map