"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.discoverPostSource = void 0;
const axios_1 = __importDefault(require("axios"));
const discoverFeedsFromHtml_1 = require("./feed/discoverFeedsFromHtml");
const discoverWordpressApiFromUrls_1 = require("./wordpress/discoverWordpressApiFromUrls");
const discoverFeedsFromUrls_1 = require("./feed/discoverFeedsFromUrls");
const discoverWordpressApiFromHeader_1 = require("./wordpress/discoverWordpressApiFromHeader");
/**
 * Looks through a site metadata in order to find a data source such as a Feed RSS.
 *
 * It's recommended to call this function once, as blog data sources rarely change.
 *
 * @param url The site URL
 * @param options The discovery options
 * @throws Error When no post source is available
 */
function discoverPostSource(url, options = {}) {
    var _a, _b, _c, _d;
    return __awaiter(this, void 0, void 0, function* () {
        const httpClient = (_a = options.axios) !== null && _a !== void 0 ? _a : axios_1.default;
        const canUseSource = (_b = options.canUseSource) !== null && _b !== void 0 ? _b : ((_) => true);
        const preferFeeds = (_c = options.preferFeeds) !== null && _c !== void 0 ? _c : false;
        const guessUrls = (_d = options.tryToGuessPaths) !== null && _d !== void 0 ? _d : false;
        const { data, headers } = yield httpClient.get(url, { responseType: 'text' });
        const steps = [];
        // Adds to the list of steps the wordpress and feed auto-discovery
        pushItems(steps, preferFeeds, () => __awaiter(this, void 0, void 0, function* () { return (0, discoverWordpressApiFromHeader_1.discoverWordpressApiFromHeader)(headers); }), () => __awaiter(this, void 0, void 0, function* () { return (0, discoverFeedsFromHtml_1.discoverFeedsFromRawHtml)(url, data); }));
        if (guessUrls) {
            // Adds to the list of steps the discovery of WP API and feed URLs by guessing
            pushItems(steps, preferFeeds, () => (0, discoverWordpressApiFromUrls_1.discoverWordpressApiFromUrls)(httpClient, url, options.wpApiPaths), () => (0, discoverFeedsFromUrls_1.discoverFeedsFromUrls)(httpClient, url, options.feedPaths));
        }
        // Tries step by step, until it finds a usable source
        for (const step of steps) {
            const sources = yield step();
            const source = sources.find(s => s && canUseSource(s));
            if (source)
                return source;
        }
        throw new Error('No post source available');
    });
}
exports.discoverPostSource = discoverPostSource;
/**
 * Push multiple items into an array
 * @param array The array
 * @param reverse Whether the items will be pushed in the reverse order
 * @param items The items to push
 */
function pushItems(array, reverse, ...items) {
    if (reverse) {
        array.push(...items.reverse());
    }
    else {
        array.push(...items);
    }
}
