"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.discoverFeedsFromUrls = void 0;
const parseRawFeed_1 = require("./parseRawFeed");
const defaultFeedPaths = [
    './feed',
    './atom',
    './rss',
    './feed.json',
    './feed.xml',
    '?feed=atom',
];
const mimeTypes = [
    'application/xml',
    'application/rss+xml',
    'application/atom+xml',
    'application/feed+json',
    'application/json',
];
/**
 * Discovers feeds by requesting specific paths and checking its responses
 *
 * @param axios The axios instance
 * @param baseUrl The base server URL
 * @param paths The path list to test upon
 */
function discoverFeedsFromUrls(axios, baseUrl, paths) {
    return __awaiter(this, void 0, void 0, function* () {
        const pathsToCheck = paths !== null && paths !== void 0 ? paths : defaultFeedPaths;
        const feeds = yield Promise.all(pathsToCheck.map(path => discoverFeedUrl(axios, new URL(path, baseUrl).href).catch(() => undefined)));
        return feeds.filter(feed => feed && feed.url);
    });
}
exports.discoverFeedsFromUrls = discoverFeedsFromUrls;
/**
 * Requests specific paths and checks its responses
 *
 * @param axios The axios instance
 * @param url The URL to test
 */
function discoverFeedUrl(axios, url) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data, status, headers, request } = yield axios.get(url, {
            responseType: 'text',
            transformResponse: data => data,
            headers: {
                Accept: mimeTypes.join(', '),
            },
            validateStatus: null,
        });
        if (status >= 400 || !data)
            return undefined;
        const type = headers['content-type'];
        const list = (0, parseRawFeed_1.parseRawFeed)(data, type);
        if (!list)
            return undefined;
        return {
            source: 'feed',
            url: request.responseURL || url,
            type: type,
            title: list.title,
        };
    });
}
