"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseFeedsFromLinks = void 0;
const wpApiRel = 'https://api.w.org/';
const validTypes = ['application/feed+json', 'application/atom+xml', 'application/rss+xml'];
const basicTypes = ['application/json', 'application/xml', 'text/json', 'text/xml'];
/**
 * Parses <link> elements into discovered feeds
 *
 * @param links The link elements
 * @param baseUrl The base URL, if any
 */
function parseFeedsFromLinks(links, baseUrl) {
    var _a, _b, _c;
    const discoveredWpApi = [];
    const discoveredFeed = [];
    for (let link of links) {
        const href = (_a = link.attribs) === null || _a === void 0 ? void 0 : _a.href;
        if (!href)
            continue;
        const type = (_b = link.attribs.type) === null || _b === void 0 ? void 0 : _b.toLowerCase();
        const rel = (_c = link.attribs.rel) === null || _c === void 0 ? void 0 : _c.toLowerCase();
        const url = new URL(href, baseUrl).href; // Resolves relative URLs
        if (rel === wpApiRel) {
            discoveredWpApi.push({
                source: 'wordpress-rest-api',
                url,
            });
            continue;
        }
        if (isValidLink(type, rel)) {
            const title = link.attribs.title;
            discoveredFeed.push({
                source: 'feed',
                url,
                type,
                title,
            });
        }
    }
    // Sorts by the type
    return [
        ...discoveredWpApi,
        ...discoveredFeed.sort((a, b) => validTypes.indexOf(a.type) - validTypes.indexOf(b.type)),
    ];
}
exports.parseFeedsFromLinks = parseFeedsFromLinks;
/**
 * Whether the link type and rel represent a valid RSS, Atom or JSON Feed files
 *
 * @param type The type attribute
 * @param rel The rel attribute
 */
function isValidLink(type, rel) {
    // whether it has a explicit feed mime type
    if (type && validTypes.includes(type))
        return true;
    // whether it has a explicit feed rel and a basic feed type
    if (rel && rel.includes('feed') && (!type || basicTypes.includes(type)))
        return true;
    return false;
}
