"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseRawFeed = void 0;
const htmlparser2_1 = require("htmlparser2");
const parseAtomFeed_1 = require("./parseAtomFeed");
const parseRssFeed_1 = require("./parseRssFeed");
const parseJsonFeed_1 = require("./parseJsonFeed");
const parseRssInJsonFeed_1 = require("./parseRssInJsonFeed");
const utils_1 = require("../utils");
const rootTags = ['rss', 'feed', 'rdf:RDF'];
/**
 * Parses a raw XML feed
 *
 * @param rawFeed The raw feed data
 * @param type The feed mime type
 */
function parseRawFeed(rawFeed, type) {
    const mightBeJson = (type === null || type === void 0 ? void 0 : type.includes('json')) ||
        (rawFeed.startsWith('{') && rawFeed.endsWith('}'));
    const mightBeXml = (type === null || type === void 0 ? void 0 : type.includes('xml')) ||
        (rawFeed.includes('<?xml') || rawFeed.includes('xmlns'));
    if (mightBeJson)
        return parseRawJsonFeed(rawFeed);
    if (mightBeXml)
        return parseRawXmlFeed(rawFeed);
    throw new Error('Unknown feed type');
}
exports.parseRawFeed = parseRawFeed;
/**
 * Parses a JSON feed
 *
 * @param rawFeed The raw feed text
 */
function parseRawJsonFeed(rawFeed) {
    rawFeed = (0, utils_1.extractFromJsonp)(rawFeed);
    const feed = JSON.parse(rawFeed);
    if ('version' in feed && feed.version.includes('jsonfeed.org'))
        return (0, parseJsonFeed_1.parseJsonFeed)(feed);
    if ('rss' in feed)
        return (0, parseRssInJsonFeed_1.parseRssInJsonFeed)(feed);
    throw new Error("Couldn't identify the type of the feed");
}
/**
 * Parses a XML feed
 *
 * @param rawFeed The raw feed text
 */
function parseRawXmlFeed(rawFeed) {
    const document = (0, htmlparser2_1.parseDocument)(rawFeed, { xmlMode: true });
    const root = htmlparser2_1.DomUtils.findOne((e) => rootTags.includes(e.name.toLowerCase()), document.children);
    if (!root)
        throw new Error("The root feed element was not found");
    if (root.name.toLowerCase() === 'feed') {
        return (0, parseAtomFeed_1.parseAtomFeed)(root);
    }
    else {
        return (0, parseRssFeed_1.parseRssFeed)(root);
    }
}
