"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseRssAuthors = void 0;
/**
 * Parses <author> or <dc:creator> element contents
 *
 * @param author The <author> contents
 * @param creator The <dc:creator> contents
 */
function parseRssAuthors(author, creator) {
    const regex = /^(.+?)(?:\s?\((.+)\))?$/m;
    let name;
    let uri;
    let email;
    if (creator) {
        const match = regex.exec(creator);
        if (match) {
            name = match[1];
            uri = match[2];
        }
        else {
            name = creator;
        }
    }
    if (author) {
        const match = regex.exec(author);
        if (match) {
            name = match[2];
            email = match[1];
        }
        else {
            email = author;
        }
    }
    if (!email && uri && uri.startsWith('mailto:'))
        email = uri.substring('mailto:'.length);
    if (!name && !uri && !email)
        return [];
    return [{ name, uri, email }];
}
exports.parseRssAuthors = parseRssAuthors;
