"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractFromJsonp = exports.convertHtmlToText = exports.getNumberByTagName = exports.getDateByTagName = exports.getTextByTagName = exports.getElementByTagName = void 0;
const htmlparser2_1 = require("htmlparser2");
function getElementByTagName(tag, nodes, recurse = true) {
    return htmlparser2_1.DomUtils.findOne(e => e.name === tag, nodes, recurse);
}
exports.getElementByTagName = getElementByTagName;
function getTextByTagName(tag, nodes, recurse = true) {
    return htmlparser2_1.DomUtils.textContent(htmlparser2_1.DomUtils.getElementsByTagName(tag, nodes, recurse));
}
exports.getTextByTagName = getTextByTagName;
function getDateByTagName(tag, nodes, recurse = true) {
    const text = getTextByTagName(tag, nodes, recurse);
    return text ? new Date(text) : undefined;
}
exports.getDateByTagName = getDateByTagName;
function getNumberByTagName(tag, nodes, recurse = true) {
    const text = getTextByTagName(tag, nodes, recurse);
    return text ? +text : undefined;
}
exports.getNumberByTagName = getNumberByTagName;
function convertHtmlToText(html) {
    return html ? htmlparser2_1.DomUtils.textContent((0, htmlparser2_1.parseDocument)(html)).trim() : undefined;
}
exports.convertHtmlToText = convertHtmlToText;
/**
 * Tries to extract a JSON string from a JSONP text
 *
 * @param raw The raw JSON/JSONP text
 */
function extractFromJsonp(raw) {
    // This regex matches JSONP results, such as `onGetFeed({ ... })`
    const jsonpRegex = /^(\w+)\s+?\(({.*})\s+?\)$/sm;
    const match = jsonpRegex.exec(raw.trim());
    return match ? match[2] : raw;
}
exports.extractFromJsonp = extractFromJsonp;
