"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.discoverWordpressApiFromUrls = void 0;
const defaultApiPaths = [
    './wp-json',
    '?rest_route=/'
];
/**
 * Discovers Wordpress API URLs by requesting and checking its response
 *
 * @param axios The axios instance
 * @param baseUrl The base URL
 * @param paths The paths to test
 */
function discoverWordpressApiFromUrls(axios, baseUrl, paths) {
    return __awaiter(this, void 0, void 0, function* () {
        const pathsToCheck = paths !== null && paths !== void 0 ? paths : defaultApiPaths;
        const apis = yield Promise.all(pathsToCheck.map(path => discoverWordpressApiUrl(axios, new URL(path, baseUrl).href).catch(() => undefined)));
        return apis.filter(api => api && api.url);
    });
}
exports.discoverWordpressApiFromUrls = discoverWordpressApiFromUrls;
/**
 * Test a URL by trying to request and check the response
 *
 * @param axios The axios instance
 * @param url The URL to test
 */
function discoverWordpressApiUrl(axios, url) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data, status, request } = yield axios.get(url, {
            responseType: 'json',
            headers: {
                Accept: 'application/json',
            },
            validateStatus: undefined,
        });
        if (status >= 400)
            return undefined;
        if (!data || typeof data !== 'object' || !data.name)
            return undefined;
        return {
            source: 'wordpress-rest-api',
            url: request.responseURL || url,
        };
    });
}
