"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchWordpressPostList = void 0;
const parseWordpressPosts_1 = require("./parseWordpressPosts");
const parseWordpressPagination_1 = require("./parseWordpressPagination");
const fetchWordpressBlogInfo_1 = require("./fetchWordpressBlogInfo");
/**
 * Fetches the Wordpress post list from the Wordpress REST API
 *
 * See https://developer.wordpress.org/rest-api/reference/
 *
 * @param axios The Axios instance
 * @param wpApiBase The base Wordpress REST API URL
 * @param page The page number
 * @param options The options
 */
function fetchWordpressPostList(axios, wpApiBase, page = 1, options = {}) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        let params = {};
        params['page'] = page;
        if ((_a = options.includeEmbedded) !== null && _a !== void 0 ? _a : true)
            params['_embed'] = true;
        if (options.limit)
            params['limit'] = options.limit;
        if (options.search)
            params['search'] = options.search;
        if (options.authors && options.authors.length > 0)
            params['author'] = options.authors;
        if (options.categories && options.categories.length > 0)
            params['categories'] = options.categories;
        if (options.tags && options.tags.length > 0)
            params['tags'] = options.tags;
        if (options.additionalParams)
            params = Object.assign(Object.assign({}, params), options.additionalParams);
        const url = '/wp/v2/posts?' + new URLSearchParams(params).toString();
        const { data, headers } = yield axios.get(url, {
            baseURL: wpApiBase,
            responseType: 'json',
            headers: {
                Accept: 'application/json',
            },
        });
        let blogInfo = {};
        if (options.fetchBlogInfo) {
            blogInfo = yield (0, fetchWordpressBlogInfo_1.fetchWordpressBlogInfo)(axios, wpApiBase, options)
                .catch(() => blogInfo);
        }
        return Object.assign(Object.assign({}, blogInfo), { container: {
                type: 'wordpress-rest-api',
                version: 'v2',
                metadata: {
                    params: params,
                }
            }, posts: (0, parseWordpressPosts_1.parseWordpressPosts)(data), pagination: (0, parseWordpressPagination_1.parseWordpressPagination)(wpApiBase, page, headers) });
    });
}
exports.fetchWordpressPostList = fetchWordpressPostList;
