"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseWordpressMedia = void 0;
const utils_1 = require("../utils");
/**
 * Parses the featured media
 *
 * See https://developer.wordpress.org/rest-api/reference/media/
 *
 * @param items The media object array
 */
function parseWordpressMedia(items) {
    var _a, _b, _c, _d;
    if (!items)
        return undefined;
    const media = [];
    for (const item of items) {
        const sizes = (_a = item.media_details) === null || _a === void 0 ? void 0 : _a.sizes;
        const title = (0, utils_1.convertHtmlToText)((_b = item.title) === null || _b === void 0 ? void 0 : _b.rendered);
        if (!sizes) {
            media.push({
                id: item.id,
                url: item.source_url,
                type: item.mime_type,
                height: (_c = item.media_details) === null || _c === void 0 ? void 0 : _c.height,
                width: (_d = item.media_details) === null || _d === void 0 ? void 0 : _d.width,
                title,
            });
            continue;
        }
        media.push(...Object.keys(sizes).map(name => {
            const size = sizes[name];
            return {
                id: item.id,
                url: size.source_url,
                type: size.mime_type,
                height: size.height,
                width: size.width,
                title,
            };
        }));
    }
    return media;
}
exports.parseWordpressMedia = parseWordpressMedia;
